@@ -1,6 +1,4 @@
-"""
-tdub command line interface
-"""
+"""tdub command line interface."""
 
 # stdlib
 import json
@@ -21,6 +19,7 @@ log = logging.getLogger("tdub-cli")
 
 @click.group(context_settings=dict(max_content_width=82, help_option_names=['-h', '--help']))
 def cli():
+    """Top Level CLI function."""
     pass
 
 
@@ -77,7 +76,6 @@ def train_prep(
     use_dilep,
 ):
     """Prepare data for training."""
-
     if pre_exec is not None:
         exec(PosixPath(pre_exec).read_text())
 
@@ -116,8 +114,8 @@ def train_prep(
     persist_prepared_data(outdir, df, y, w)
     (outdir / "region.txt").write_text(f"{region}\n")
     (outdir / "nlo_method.txt").write_text(f"{nlo_method}\n")
-    (outdir / "files_sig.txt").write_text("{}\n".format(("\n".join(sig_files))))
-    (outdir / "files_bkg.txt").write_text("{}\n".format(("\n".join(bkg_files))))
+    (outdir / "files_sig.txt").write_text("{}\n".format("\n".join(sig_files)))
+    (outdir / "files_bkg.txt").write_text("{}\n".format("\n".join(bkg_files)))
 
 
 @train.command("single")
@@ -148,7 +146,6 @@ def train_single(
     reg_lambda,
 ):
     """Execute single training round."""
-
     if pre_exec is not None:
         exec(PosixPath(pre_exec).read_text())
 
@@ -213,7 +210,6 @@ def train_scan(
     $ tdub train scan /data/path 2j2b scan_2j2b
 
     """
-
     if pre_exec is not None:
         exec(PosixPath(pre_exec).read_text())
 
@@ -503,7 +499,7 @@ def apply_all(
     single_results=None,
     and_submit=False,
 ):
-    """Generate BDT response arrays for all ROOT files in DATAIR"""
+    """Generate BDT response arrays for all ROOT files in DATADIR."""
     import glob
     import shutil
     import pycondor
@@ -584,56 +580,109 @@ def itables(summary_file):
     """))
 
 
+@train.command("shapes")
+@click.argument("datadir", type=click.Path(exists=True))
+@click.option("-o", "--outdir", type=click.Path(), help="Directory to save output.")
+def train_shapes(datadir, outdir):
+    """Generate shape comparion plots."""
+    if outdir is None:
+        outdir = PosixPath.cwd()
+    else:
+        outdir = PosixPath(outdir)
+        outdir.mkdir(exist_ok=True, parents=True)
+
+    import tdub.internal.shapecomps as tdisc
+    import tdub.ml_train as tdmlt
+    import tdub.config
+    tdub.config.init_meta_table()
+    meta_table = tdub.config.PLOTTING_META_TABLE
+    datadir = PosixPath(datadir)
+    region = (datadir / "region.txt").read_text().strip()
+    df, y, w = tdmlt.load_prepped(datadir)
+    var_region_binning = tdmlt.var_and_binning_for_region(df, region, meta_table)
+    for v, r, b in var_region_binning:
+        tdisc.dist_comparison_plot(v, r, b, df, y, w, meta_table, outdir=outdir)
+
+
 @rex.command("stacks")
-@click.argument("workspace", type=click.Path(exists=True))
+@click.argument("rex-dir", type=click.Path(exists=True))
 @click.option("--chisq/--no-chisq", default=True, help="Do or don't print chi-square information.")
 @click.option("-n", "--n-test", type=int, default=-1, help="Test only n plots (for stacks).")
-def rex_stacks(workspace, chisq, n_test):
+@click.option("--thesis", is_flag=True, help="Use thesis label")
+def rex_stacks(rex_dir, chisq, n_test, thesis):
     """Generate plots from TRExFitter result."""
     import tdub.rex
     import tdub.config
-    outdir = PosixPath(workspace) / "matplotlib"
+    outdir = PosixPath(rex_dir) / "matplotlib"
     outdir.mkdir(exist_ok=True)
     tdub.config.init_meta_table()
     tdub.config.init_meta_logy()
-    tdub.rex.plot_all_regions(workspace, outdir, stage="pre", show_chisq=chisq, n_test=n_test)
-    tdub.rex.plot_all_regions(workspace, outdir, stage="post", show_chisq=chisq, n_test=n_test)
+    if thesis:
+        tdub.config.IS_THESIS = True
+    tdub.rex.plot_all_regions(
+        rex_dir, outdir, stage="pre", show_chisq=chisq, n_test=n_test, thesis=thesis
+    )
+    tdub.rex.plot_all_regions(
+        rex_dir, outdir, stage="post", show_chisq=chisq, n_test=n_test, thesis=thesis
+    )
     return 0
 
 
 @rex.command("impact")
-@click.argument("workspace", type=click.Path(exists=True))
-def rex_impact(workspace, outdir):
+@click.argument("rex-dir", type=click.Path(exists=True))
+@click.option("--thesis", is_flag=True, help="Flat to use thesis label.")
+def rex_impact(rex_dir, thesis):
     """Generate impact plot from TRExFitter result."""
     import tdub.rex
-    tdub.rex.nuispar_impact_plot_top15(workspace)
+    tdub.rex.nuispar_impact_plot_top20(rex_dir, thesis=thesis)
     return 0
 
 
+@rex.command("stabs")
+@click.argument("umbrella", type=click.Path(exists=True))
+@click.option("-o", "--outdir", type=click.Path(), help="Output directory.")
+@click.option("-t", "--tests", type=str, multiple=True, help="Tests to run.")
+def rex_stabs(umbrella, outdir, tests):
+    """Generate stability tests based on rexpy output."""
+    import tdub.rex
+    if outdir is not None:
+        outdir = PosixPath(outdir)
+    if len(tests) == 0 or "all" in tests:
+        tests = "all"
+    tdub.rex.stability_test_standard(PosixPath(umbrella), outdir=outdir, tests=tests)
+
+
+@rex.command("impstabs")
+@click.argument("herwig704", type=click.Path(exists=True))
+@click.argument("herwig713", type=click.Path(exists=True))
+@click.option("-o", "--outdir", type=click.Path(), help="Output directory.")
+def rex_impstabs(herwig704, herwig713, outdir):
+    """Generate impact stability tests based on rexpy output."""
+    import tdub.rex
+    if outdir is not None:
+        outdir = PosixPath(outdir)
+    tdub.rex.stability_test_parton_shower_impacts(
+        PosixPath(herwig704),
+        PosixPath(herwig713),
+        outdir=outdir,
+    )
+
+
 @misc.command("soverb")
 @click.argument("datadir", type=click.Path(exists=True))
 @click.argument("selections", type=click.Path(exists=True))
 @click.option("-t", "--use-tptrw", is_flag=True, help="use top pt reweighting")
-def soverb(datadir, selections, use_tptrw):
+def misc_soverb(datadir, selections, use_tptrw):
     """Get signal over background using data in DATADIR and a SELECTIONS file.
 
     the format of the JSON entries should be "region": "numexpr selection".
 
-    Example SELECTIONS file:
-
-    \b
-    {
-        "reg1j1b" : "(mass_lep1lep2 < 150) & (mass_lep2jet1 < 150)",
-        "reg1j1b" : "(mass_jet1jet2 < 150) & (mass_lep2jet1 < 120)",
-        "reg2j2b" : "(met < 120)"
-    }
-
     """
     from tdub.frames import raw_dataframe, apply_weight_tptrw, satisfying_selection
     from tdub.data import quick_files
     from tdub.data import selection_branches
 
-    with open(selections, "r") as f:
+    with open(selections) as f:
         selections = json.load(f)
 
     necessary_branches = set()
@@ -654,7 +703,27 @@ def soverb(datadir, selections, use_tptrw):
         print(sel, s_df["weight_nominal"].sum() / b_df["weight_nominal"].sum())
 
 
+@misc.command("drdscomps")
+@click.argument("datadir", type=click.Path(exists=True))
+@click.option("-o", "--outdir", type=click.Path(), help="Output directory.")
+@click.option("--thesis", is_flag=True, help="Flag for thesis label.")
+def misc_drdscomps(datadir, outdir, thesis):
+    """Generate plots comparing DR and DS (with BDT cuts shown)."""
+    import tdub.internal.drds as tdid
+
+    curdir = PosixPath.cwd().resolve()
+    if outdir is not None:
+        outdir = PosixPath(outdir).resolve()
+    else:
+        outdir = curdir
+    outdir.mkdir(exist_ok=True, parents=True)
+    os.chdir(outdir)
+    tdid.bdt_cut_plots(datadir, thesis=thesis)
+    os.chdir(curdir)
+
+
 def run_cli():
+    """Run main CLI."""
     import tdub.config
     tdub.config.AVOID_IN_CLF_1j1b = []
     tdub.config.AVOID_IN_CLF_2j1b = []
