@@ -12,9 +12,9 @@ from typing import Union, Set, Dict, Iterable, List, Optional
 
 # external
 import formulate
-import uproot4 as uproot
-from uproot4.reading import ReadOnlyDirectory
-from uproot4.behaviors.TTree import TTree
+import uproot
+from uproot.reading import ReadOnlyDirectory
+from uproot.behaviors.TTree import TTree
 
 # tdub
 import tdub.config
@@ -275,7 +275,7 @@ def branches_from(
     ["pT_lep1", "pT_lep2", "weight_nominal", "weight_tptrw"]
 
     """
-    if isinstance(source, (str, os.PathLike)):
+    if isinstance(source, (str, PosixPath)):
         t = uproot.open(source).get(tree)
     elif isinstance(source, list):
         t = uproot.open(source[0]).get(tree)
