@@ -387,7 +387,7 @@ def prepare_from_root(
 
     if override_selection is not None:
         selection = override_selection
-        log.info("Overriding selection (in region %s) to %s" % (region, override_selection))
+        log.info(f"Overriding selection (in region {region}) to {override_selection}")
     else:
         selection = selection_for(region)
     selection = selection_as_numexpr(selection)
@@ -945,6 +945,7 @@ def single_training(
     # Plot Importances
     if use_lgbm:
         import lightgbm as lgbm
+
         fig_imp, (ax_imp_gain, ax_imp_split) = plt.subplots(2, 1)
         lgbm.plot_importance(model, ax=ax_imp_gain, importance_type="gain", precision=2)
         lgbm.plot_importance(model, ax=ax_imp_split, importance_type="split", precision=2)
@@ -1131,7 +1132,7 @@ def folded_training(
 
     tprs = []
     aucs = []
-    importances = np.zeros((len(df.columns)))
+    importances = np.zeros(len(df.columns))
     mean_fpr = np.linspace(0, 1, 100)
     folder = KFold(**kfold_kw, random_state=tdub.config.RANDOM_STATE)
     fold_number = 0
@@ -1600,3 +1601,56 @@ def gp_minimize_auc(
 
     os.chdir(run_from_dir)
     return 0
+
+
+def load_prepped(datadir: PosixPath) -> Tuple[pd.DataFrame, np.ndarray, np.ndarray]:
+    """Load prepped training data.
+
+    Parameters
+    ----------
+    datadir : pathlib.PosixPath
+        Path to the preppared output.
+
+    Returns
+    -------
+    :py:obj:`pandas.DataFrame`
+        DataFrame containing training variables
+    :py:obj:`numpy.ndarray`
+        Labels for each event.
+    :py:obj:`numpy.ndarray`
+        Weights for each event.
+
+    """
+    df = pd.read_hdf(datadir / "df.h5", "df")
+    y = np.load(datadir / "labels.npy")
+    w = np.load(datadir / "weights.npy")
+    return df, y, w
+
+
+def var_and_binning_for_region(
+    df: pd.DataFrame, region: Union[str, Region], meta_table: Any
+) -> Any:
+    """Create list of training variables associated with a region.
+
+    Parameters
+    ----------
+    df : pandas.DataFrame
+        DataFrame containg training variables
+    region : str
+        String representation of region.
+    meta_table : dict(str, Any)
+        Variable meta data table.
+
+    Returns
+    -------
+    list
+        List of variables with associated region and binning.
+    """
+    results = []
+    cols = list(df.columns)
+    for entry in meta_table["regions"][f"r{str(Region.from_str(str(region)))}"]:
+        if entry["var"] in cols:
+            results.append(
+                (entry["var"], region, (entry["nbins"], entry["xmin"], entry["xmax"]))
+            )
+    return results
