@@ -19,8 +19,8 @@ matplotlib.use("pdf")
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
-import uproot4 as uproot
-from uproot4.reading import ReadOnlyDirectory
+import uproot
+from uproot.reading import ReadOnlyDirectory
 
 import yaml
 
@@ -80,7 +80,7 @@ class FitParam:
 
     def __post_init__(self):
         """Execute after init."""
-        self.post_max = max(abs(self.post_down), abs(self.post_up))
+        self.post_max: float = max(abs(self.post_down), abs(self.post_up))
 
 
 def available_regions(rex_dir: Union[str, os.PathLike]) -> List[str]:
@@ -188,7 +188,7 @@ def prefit_histogram(root_file: ReadOnlyDirectory, sample: str, region: str) ->
 
     Parameters
     ----------
-    root_file : uproot4.reading.ReadOnlyDirectory
+    root_file : uproot.reading.ReadOnlyDirectory
         File containing the desired prefit histogram.
     sample : str
         Physics sample name.
@@ -321,7 +321,7 @@ def postfit_histogram(root_file: ReadOnlyDirectory, sample: str) -> TH1:
 
     Parameters
     ----------
-    root_file : uproot4.reading.ReadOnlyDirectory
+    root_file : uproot.reading.ReadOnlyDirectory
         File containing the desired postfit histogram.
     sample : str
         Physics sample name.
@@ -604,9 +604,6 @@ def plot_region_stage_ff(args):
     )
     output_file = f"{args[2]}/{args[1]}_{args[3]}Fit.pdf"
     fig.savefig(output_file)
-    plt.close(fig)
-    del fig, ax0, ax1
-    log.info("Created %s" % output_file)
 
 
 def plot_all_regions(
@@ -650,6 +647,8 @@ def plot_all_regions(
     ]
     pool = multiprocessing.Pool(processes=multiprocessing.cpu_count())
     pool.map(plot_region_stage_ff, args)
+    plt.close("all")
+    log.info("Done creating %s-fit plots in %s." % (stage, outdir))
 
 
 def nuispar_impact(
@@ -863,7 +862,6 @@ def nuispar_impact_plot_top20(
     fig.savefig(output_file)
     log.info("Created %s" % output_file)
     plt.close(fig)
-    del fig, ax, ax2
     # fmt: on
     return 0
 
